@@ -10,6 +10,7 @@ from ..toolkit import Metric as EvMetric
 from ..toolkit import SrmCheck as EvSrmCheck
 from ..toolkit import SumRatioCheck as EvSumRatioCheck
 from ..toolkit import Parser
+from ..toolkit import DEFAULT_CONFIDENCE_LEVEL, DEFAULT_POWER
 
 
 class Metric(BaseModel):
@@ -38,6 +39,12 @@ class Metric(BaseModel):
         description="""EP metric is defined in the form of `nominator / denominator`.
         Both parts are entered as expressions. Example: `count(my_unit_type.unit.conversion)`.""",
     )
+    minimum_effect: Optional[float] = Field(
+        title="Minimum effect of interest",
+        description=f"""The minimum effect of interest is the smallest relative difference that is meaningful to detect,
+        defining it allows us to estimate the size of the sample data required to reach {DEFAULT_POWER:.0%} power.""",
+        default=None,
+    )
 
     @validator("id")
     def id_must_be_not_empty(cls, value):
@@ -79,7 +86,13 @@ class Metric(BaseModel):
             raise ValueError(f"Cannot parse nominator '{nominator}' or '{denominator}' because of '{e}'")
 
     def to_metric(self):
-        return EvMetric(self.id, self.name, self.nominator, self.denominator)
+        return EvMetric(
+            id=self.id,
+            name=self.name,
+            nominator=self.nominator,
+            denominator=self.denominator,
+            minimum_effect=self.minimum_effect,
+        )
 
 
 class Check(BaseModel):
@@ -370,3 +383,53 @@ class Experiment(BaseModel):
                 ],
             }
         }
+
+
+class SampleSizeCalculationData(BaseModel):
+    """
+    Data needed for the sample size calculation.
+    """
+
+    n_variants: int = Field(
+        title="Number of variants",
+        description="Number of variants in the experiment.",
+    )
+
+    minimum_effect: float = Field(
+        title="Minimum effect of interest",
+        description="Relative effect, must be greater than zero.",
+    )
+
+    mean: float = Field(
+        title="Current mean",
+        description="""Estimate of the current population mean. If `std` is empty,
+        it is assumed that the data comes from Bernoulli distribution. In such case,
+        `mean` must be between zero and one.""",
+    )
+
+    std: Optional[float] = Field(
+        title="Current standard deviation",
+        description="""Estimate of the current population standard deviation. If empty,
+        it is assumed that the data comes from Bernoulli distribution. In such case,
+        `mean` must be between zero and one.""",
+    )
+
+    confidence_level: float = Field(
+        title="Confidence level",
+        default=DEFAULT_CONFIDENCE_LEVEL,
+    )
+
+    power: float = Field(
+        title="Power",
+        default=DEFAULT_POWER,
+    )
+
+    class Config:
+        schema_extra = {
+            "example": {
+                "minimum_effect": 0.1,
+                "mean": 0.2,
+                "std": 1.2,
+                "n_variants": 2,
+            }
+        }
