@@ -3,4 +3,4 @@ from .metric import Metric, SimpleMetric
 from .check import Check, SrmCheck, SimpleSrmCheck, SumRatioCheck
 from .parser import Parser, EpGoal
 from .dao import Dao, DaoFactory
-from .statistics import Statistics
+from .statistics import Statistics, DEFAULT_CONFIDENCE_LEVEL, DEFAULT_POWER
