@@ -1,9 +1,13 @@
 import pandas as pd
 import numpy as np
 import scipy.stats as st
+from typing import Optional, Union
 from statsmodels.stats.multitest import multipletests
 import warnings
 
+DEFAULT_CONFIDENCE_LEVEL = 0.95
+DEFAULT_POWER = 0.8
+
 
 class Statistics:
     """
@@ -111,7 +115,7 @@ class Statistics:
                 # We fill in zeros, when goal data are missing for some variant.
                 # There could be division by zero here which is expected as we return
                 # nan or inf values to the caller.
-                rel_diff = (mean_treat - mean_cont) / mean_cont
+                rel_diff = (mean_treat - mean_cont) / np.abs(mean_cont)
                 # standard error for relative difference
                 rel_se = (
                     np.sqrt(
@@ -160,7 +164,7 @@ class Statistics:
 
     @classmethod
     def multiple_comparisons_correction(
-        cls, df: pd.DataFrame, variants: int, metrics: int, confidence_level: float
+        cls, df: pd.DataFrame, n_variants: int, metrics: int, confidence_level: float
     ) -> pd.DataFrame:
         """
         [Holm-Bonferroni correction](https://en.wikipedia.org/wiki/Holm%E2%80%93Bonferroni_method)
@@ -178,7 +182,7 @@ class Statistics:
 
         Arguments:
             df: dataframe as output of [`ttest_evaluation`][epstats.toolkit.statistics.Statistics.ttest_evaluation]
-            variants: number of variants in the experiment
+            n_variants: number of variants in the experiment
             metrics: number of metrics of experiment
             confidence_level: desired confidence level at the end of the experiment, e.g. 0.95
 
@@ -189,8 +193,8 @@ class Statistics:
 
         for m in range(metrics):
             # indices of rows with metric m data
-            index_from = m * variants + 1
-            index_to = (m + 1) * variants - 1
+            index_from = m * n_variants + 1
+            index_to = (m + 1) * n_variants - 1
 
             # p-value adjustment
             pvals = df.loc[index_from:index_to, "p_value"].to_list()  # select old p-values
@@ -204,7 +208,7 @@ class Statistics:
             f = df.loc[index_from:index_to, "degrees_of_freedom"].to_list()  # degrees of freedom
             se = df.loc[index_from:index_to, "standard_error"].to_list()  # standard error
 
-            t_quantile = st.t.ppf(np.ones(variants - 1) - adj_alpha + adj_alpha / 2, f)  # right t-quantile
+            t_quantile = st.t.ppf(np.ones(n_variants - 1) - adj_alpha + adj_alpha / 2, f)  # right t-quantile
             adj_conf_int = se * t_quantile  # adjusted confidence interval
 
             # replace (unadjusted) p-values and confidence intervals with new adjusted ones
@@ -233,3 +237,131 @@ class Statistics:
         q = st.norm.ppf(1 - alpha / 2)  # quantile of normal distribution
         alpha_adj = 2 - 2 * st.norm.cdf(q / np.sqrt(t))
         return np.round(1 - alpha_adj, decimals=4)
+
+    @staticmethod
+    def required_sample_size_per_variant(
+        n_variants: int,
+        minimum_effect: float,
+        mean: float,
+        std: float,
+        std_2: Optional[float] = None,
+        confidence_level: float = DEFAULT_CONFIDENCE_LEVEL,
+        power: float = DEFAULT_POWER,
+    ) -> Union[int, float]:
+        """
+        Computes the sample size required to reach the defined `confidence_level` and `power`.
+
+        Uses the following formula:
+
+        $$
+        N = \\frac{(Z_{1-\\alpha/2} + Z_{1-\\beta})^2(s_1^2 + s_2^2)}{\\Delta^2}
+        $$
+
+        where $\\Delta = \\mathrm{MEI}\\mu_1$. When `std_2` is unknown,
+        we assume equal variance $s_1^2 = s_2^2$:
+
+        $$
+        N = \\frac{(Z_{1-\\alpha/2} + Z_{1-\\beta})^2 2s_1^2}{\\Delta^2}
+        $$
+
+        For `confidence_level = 0.95` and `power = 0.8`:
+        $$
+        N = \\frac{7.84 * 2s_1^2}{\\Delta^2} = \\frac{15.7s_1^2}{\\Delta^2}
+        $$
+
+        The calculation is using Bonferroni correction when `n_variants > 2`. The initial
+        $\\alpha$ defined by the `confidence_level` parameter is adjusted to
+
+        $$
+        \\alpha^{*} = \\alpha / m
+        $$
+
+        where $m$ is the number of treatment variants. This correction produces
+        greater total sample size than Holm-Bonferroni correction because it assigns
+        the most conservative $\\alpha^{*}$ to all variants.
+
+        Arguments:
+            n_variants: number of variants in the experiment
+            minimum_effect: minimum (relative) effect that we find meaningful to detect
+            mean: estimate of the current population mean,
+            also known as rate in case of Bernoulli distribution
+            std: estimate of the current population standard deviation
+            std_2: estimate of the treatment population standard deviation
+            confidence_level: confidence level of the test
+            power: power of the test
+
+        Returns:
+            required sample size
+        """
+
+        if minimum_effect < 0:
+            raise ValueError("minimum_effect must be greater than zero.")
+
+        if n_variants < 2:
+            raise ValueError("There must be at least two variants.")
+
+        two_vars = 2 * (std ** 2) if std_2 is None else (std ** 2 + std_2 ** 2)
+        delta = np.float64(mean * minimum_effect)
+
+        alpha = 1 - confidence_level
+        m = n_variants - 1
+        alpha = alpha / m  # Bonferroni correction
+        # 7.84 for 80% power and 95% confidence, alpha / 2 for two-sided hypothesis
+        confidence_and_power = (st.norm.ppf(1 - alpha / 2) + st.norm.ppf(power)) ** 2
+        with np.errstate(divide="ignore", invalid="ignore"):
+            samples_size_per_variant = confidence_and_power * (two_vars / delta ** 2)
+        return np.round(samples_size_per_variant)
+
+    @classmethod
+    def required_sample_size_per_variant_bernoulli(
+        cls,
+        n_variants: int,
+        minimum_effect: float,
+        mean: float,
+        confidence_level: float = DEFAULT_CONFIDENCE_LEVEL,
+        power: float = DEFAULT_POWER,
+        **unused_kwargs,
+    ) -> Union[int, float]:
+        """
+        Computes the sample size required to reach the defined `confidence_level`
+        and `power` when the data follow Bernoulli distribution
+
+        Uses `Statistics.required_sample_size_per_variant` with `std_2` defined as
+
+        $$
+        p_2 = p_1(1 + \\mathrm{MEI}) \\\\
+        s_2^2 = p_2(1 - p_2) \\\\
+        $$
+
+        Arguments:
+            n_variants: number of variants in the experiment
+            minimum_effect: minimum (relative) effect that we find meaningful to detect
+            mean: estimate of the current population mean,
+                  also known as rate in case of Bernoulli distribution
+            confidence_level: confidence level of the test
+            power: power of the test
+
+        Returns:
+            required sample size
+        """
+
+        if mean > 1 or mean < 0:
+            raise ValueError(f"mean must be between zero and one, received {mean}.")
+
+        # if we know minimum effect, we know treatment mean and treatment variance
+        # see https://github.com/bookingcom/powercalculator/blob/master/src/js/math.js#L113
+
+        def get_std(mean):
+            return np.sqrt(mean * (1 - mean))
+
+        mean_2 = mean * (1 + minimum_effect)
+
+        return cls.required_sample_size_per_variant(
+            n_variants=n_variants,
+            minimum_effect=minimum_effect,
+            mean=mean,
+            std=get_std(mean),
+            std_2=get_std(mean_2),
+            confidence_level=confidence_level,
+            power=power,
+        )
